coinor.blimpy.LinkedList'.Node

Package coinor :: Package blimpy :: Module LinkedList' :: Class Node |
[hide private]
[frames] | no frames]

# Class Node

source code

Basic data type that LinkedList will contain pre: data that node will contain post: Node type object

Instance Methods | [hide private]
__init__(self, initdata, nextNode=None) constructor of Node class pre: Node class object (self), initial data (initdata) | source code
__repr__(self) repr(x) | source code
__str__(self) str(x) | source code
getData(self) class method that returns to data pre: self post: data of the Node | source code
getNext(self) | source code
setData(self, newdata) class method that sets data pre: self, new data | source code
setNext(self, newnext) class method that changes the next Node pre: self, new next | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, initdata, nextNode=None) (Constructor) | source code
constructor of Node class pre: Node class object (self), initial data (initdata) Overrides: object.__init__

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)